"""
This file demonstrates writing tests using the unittest module. These will pass
when you run "manage.py test".

Replace this with more appropriate tests for your application.
"""

from qa_dashboard.settings import API_TOKEN
from django.test import TestCase
from django.test.client import Client

import datetime
import json


from dashboard.models import Run, Build, Result, Bug

class PostTest(TestCase):
    def test_add_bug_post_success(self):
        """
        Tests that /api/smoke/run/XXX/image/XXX/result/XXX/add_bug/ works.
        """
        run = Run.objects.create(
                release='quantal',
                flavor='ubuntu',
                build_no='20120706',
                ran_at=datetime.datetime.now(),
                )

        c = Client()
        response = c.get('/api/smoke/run/')
        print("response: {}".format(response))

        data = json.loads(response.content)
        print("bug: data: {}".format(data))

    def test_smoke_add_result_post_success(self):
        """
        Tests that /api/add_result/ works correctly.
        """
        c = Client()
        response = c.post('/api/add_result/', {
            'name': 'quantal-desktop-amd64_default',
            'pass_count': 1,
            'fail_count': 2,
            'skip_count': 3,
            'token': API_TOKEN,
            'build_name': 'quantal-desktop-amd64_default',
            'flavor': 'ubuntu',
            'ran_at': '2012-09-01 13:00',
            'build_no': '20120901.1',
            'result_type': 'smoke',
            })
        print("response: {}".format(response))

        data = json.loads(response.content)
        print("result: data: {}".format(data))

        self.assertFalse('result' in data)

    def test_add_result_post_success(self):
        """
        Tests that /api/add_result/ works correctly.
        """
        c = Client()
        name = 'sru_kernel-quantal-generic-amd_64-vga'
        response = c.post('/api/add_result/', {
            'name': name,
            'pass_count': 1,
            'fail_count': 2,
            'skip_count': 3,
            'token': API_TOKEN,
            'build_name': name,
            'release': 'quantal',
            'version': '3.5.6',
            'variant': 'generic',
            'arch': 'amd64',
            'job_type': 'sru_kernel',
            'flavor': 'ubuntu',
            'ran_at': '2012-09-01 13:00',
            'build_no': '20120901.1',
            'result_type': 'kernel-sru',
            })
        print("response: {}".format(response))

        data = json.loads(response.content)
        print("result: data: {}".format(data))

        self.assertFalse('result' in data, "data: {}".format(data))

from dashboard.models import (
        Image,
        Machine,
        ImageResult,
        )

class BootspeedTest(TestCase):
    def test_add_image(self):
        image = Image.objects.create(
                release='quantal',
                variant='desktop',
                arch='amd64',
                build_number='20120911',
                md5='xxxx',
                )

        print("Added Image...")
        print(image)

        machine = Machine.objects.create(
                name='Dell Optiplex',
                mac_address='00:00:00:00:01',
                )

        print("Added Machine...")
        print(machine)

        kernel_init=1.1
        kernel=4.4
        plumbing=10.1
        xorg=9
        desktop=12

        boot = kernel_init + kernel + plumbing + xorg + desktop

        image.imageresult_set.create(
                machine=machine,
                ran_at=datetime.datetime.now(),
                kernel_init=kernel_init,
                kernel=kernel,
                plumbing=plumbing,
                xorg=xorg,
                desktop=desktop,
                boot=boot,
                )

        print("Added ImageResult...")
        print(image.imageresult_set.all()[0])

class SimpleTest(TestCase):
    def test_basic_addition(self):
        """
        Tests that 1 + 1 always equals 2.
        """
        self.assertEqual(1 + 1, 2)
