import json

from django.shortcuts import render_to_response
from django.views.decorators.csrf import csrf_exempt
from django.views.decorators.http import (
        require_GET,
        require_POST,
        )

from dashboard.forms import (
        ResultSmokeAddForm,
        ResultKernelSRUAddForm,
        BugForm,
        )
from dashboard.utils import (
        JSONResponse,
        require_API_TOKEN,
        )

@require_GET
def api_help(request):
    return render_to_response('api_help.html')

@require_POST
@csrf_exempt
@require_API_TOKEN
def api_add_result(request):
    """
    Generic result adder that depends on the payload containing an 
    indication of the type of test result being submitted.
    """

    # Useful for debugging
    # curl -d "build_no=20120820&flavor=ubuntu&ran_at=2012-08-20 12:00&build_name=precise-server-amd64_raid10&result_name=a&pass_count=1&fail_count=2&skip_count=3&result_type=smoke&token=XXXXXXXXXXX" localhost:8000/api/add_result/

    data = {'result': 'failure'}

    # based on the 'result_type' call the appropriate method to handle
    # adding the result.
    if request.POST.get('result_type') == "smoke":
        from dashboard.views.api.smoke import api_add_result
        return api_add_result(request)
    elif request.POST.get('result_type') == "kernel-sru":
        from dashboard.views.api.sru import api_add_result
        return api_add_result(request)
    else:
        form = None

    if form is not None:
        if form.is_valid():
            data['result'] = 'succcess'
        else:
            data['errors'] = form.errors
    

    return JSONResponse(json.dumps(data))
