import os
import sys

# Set up the environment
sys.path.append(os.path.join(os.path.dirname(__file__), '..'))
os.environ['DJANGO_SETTINGS_MODULE'] = 'qa_dashboard.settings'

import datetime
import random
from django.db import models

from dashboard.models import (
        Image,
        ImageResult,
        Machine,
        )

def randval(max=20):
    return random.random() * max

def setUp(count=10):
    image, new_image = Image.objects.get_or_create(
            release='quantal',
            variant='server',
            arch='amd64',
            md5='xyz',
            build_number='20120912',
            )

    print("DEBUG: new_image: {}".format(new_image))

    machine, new_machine = Machine.objects.get_or_create(
            name='Dell Laptop',
            mac_address='00:01:02:03:04',
            )

    # Only add results to the image once.
    if not new_image:
        return

    for i in range(count):
        kernel=randval()
        kernel_init=randval()
        plumbing=randval()
        xorg=randval()
        desktop=randval()
        boot = kernel + kernel_init + plumbing + xorg + desktop

        result = ImageResult.objects.create(
                image=image,
                machine=machine,
                kernel=kernel,
                kernel_init=kernel_init,
                plumbing=plumbing,
                xorg=xorg,
                desktop=desktop,
                boot=boot,
                ran_at=datetime.datetime.now(),
                )

setUp()

images = Image.objects.annotate(num_results=models.Count('imageresult')).filter(num_results__gt=1)

for image in images:
    print image, image.id, image.num_results

images = Image.objects.values('build_number').annotate(avg_boot=models.Avg('imageresult__boot'), max_boot=models.Max('imageresult__boot'), min_boot=models.Min('imageresult__boot'))

for image in images:
    print image
